.. image:: https://img.shields.io/pypi/v/grappelli-safe.svg
   :target: https://pypi.org/project/grappelli-safe/
.. image:: https://img.shields.io/pypi/pyversions/grappelli-safe.svg
.. image:: https://github.com/stephenmcd/grappelli-safe/workflows/Test%20and%20release/badge.svg
   :target: https://github.com/stephenmcd/grappelli-safe/actions?query=workflow%3A%22Test+and+release%22
.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
   :target: https://github.com/psf/black

Overview
========

grappelli_safe is a permanent fork of
`Grappelli admin skin <https://code.google.com/p/django-grappelli/>`_ for
`Django <https://www.djangoproject.com/>`_, to be referenced as a
dependency for the `Mezzanine CMS for Django <http://mezzanine.jupo.org/>`_.

At the time of grappelli_safe's creation, Grappelli was incorrectly
packaged on `PyPI <https://pypi.python.org/pypi>`_, and had also dropped
compatibility with Django 1.1 -- grappelli_safe was therefore created to
address these specific issues.

For further details, see
`Why are Grappelli and Filebrowser Forked? <http://mezzanine.jupo.org/docs/frequently-asked-questions.html#grappelli-filebrowser-forks>`_.

Contributing
============

Please refer to `Mezzanine's Contribution Guidelines <https://github.com/stephenmcd/mezzanine/blob/master/CONTRIBUTING.rst>`_
